import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import { withStyles } from "@material-ui/core/styles";
import {
  Button,
  Fab,
  Chip,
  Grid,
  Dialog,
  DialogTitle,
  DialogContent,
  DialogActions,
  TextField,
  FormControl,
  Input,
  InputLabel,
  InputAdornment,
  Select,
  MenuItem,
  Paper,
  Typography,
  Divider,
  Table,
  TableCell,
  TableHead,
  TableRow,
  TableBody,
  TableFooter,
  TablePagination,
  IconButton,
  ListItemIcon,
  ListItemText,
  Menu,
  Tabs,
  Tab
} from "@material-ui/core";
import Slider from "@material-ui/lab/Slider";
import DateFnsUtils from "@date-io/date-fns";
import {
  MuiPickersUtilsProvider,
  KeyboardDatePicker
} from "@material-ui/pickers";
import MoreHoriz from "@material-ui/icons/MoreHoriz";
import SearchIcon from "@material-ui/icons/Search";
import CheckBoxIcon from "@material-ui/icons/CheckBox";
import SendIcon from "@material-ui/icons/Send";
import SpeakerNotesIcon from "@material-ui/icons/SpeakerNotes";
import SpeakerNotesOutlinedIcon from "@material-ui/icons/SpeakerNotesOutlined";
import SpeakerNotesOffOutlinedIcon from "@material-ui/icons/SpeakerNotesOffOutlined";
import PersonAddIcon from "@material-ui/icons/PersonAdd";
import PersonAddDisabledIcon from "@material-ui/icons/PersonAddDisabled";
import FilterIcon from "@material-ui/icons/FilterList";
const useStyles = makeStyles(theme => ({
  root: {
    width: "100%"
  },
  paper: {
    margin: 12,
    paddingTop: 6,
    paddingBottom: 6
  },
  table: {
    minWidth: 650
  },
  grid: {
    width: "60%"
  },
  chip: {
    margin: theme.spacing(1)
  },
  dialogTitle: {
    color: "grey"
  },
  dialogContent: {
    padding: 0
  },
  paperHeader: {
    color: "grey",
    padding: "12px"
  },
  paperHeaderAction: {
    padding: 12
  },
  item: {
    paddingLeft: "12px",
    paddingRight: "12px"
  },
  formContainer: {
    display: "flex"
  },
  selectItem: {
    width: "100%"
  },
  formInput: {
    margin: 6
  },
  tabs: {
    borderBottom: "1px solid #e8e8e8"
  },
  fab: {
    position: "absolute",
    bottom: theme.spacing(2),
    right: theme.spacing(2)
  }
}));

function createData(a, b, c, d, e, f, g, h) {
  return { a, b, c, d, e, f, g, h };
}

const rows = [
  createData(
    "CIB00001",
    "Juilöa Health Centre",
    "22/12/2018",
    "Idle",
    "Idle",
    "1,000.00",
    "",
    "Entered"
  ),
  createData(
    "CID00001",
    "Viru Dispensary",
    "03/01/2018",
    "Selected for Feedback",
    "Idle",
    "2,920.00",
    "",
    "Entered"
  )
];

const StyledMenu = withStyles({
  paper: {
    border: "1px solid #d3d4d5"
  }
})(props => (
  <Menu
    elevation={0}
    getContentAnchorEl={null}
    anchorOrigin={{
      vertical: "bottom",
      horizontal: "center"
    }}
    transformOrigin={{
      vertical: "top",
      horizontal: "center"
    }}
    {...props}
  />
));

const StyledMenuItem = withStyles(theme => ({
  root: {
    "&:focus": {
      backgroundColor: theme.palette.primary.main,
      "& .MuiListItemIcon-root, & .MuiListItemText-primary": {
        color: theme.palette.common.white
      }
    }
  }
}))(MenuItem);

function TabContainer(props) {
  return (
    <Typography component="div" style={{ padding: 8 * 3 }}>
      {props.children}
    </Typography>
  );
}

export default function DenseTable() {
  const classes = useStyles();
  const [anchorEl, setAnchorEl] = React.useState(null);
  const [open, setOpen] = React.useState(false);
  const [filterTab, setFilterTab] = React.useState(1);
  const [randomValue, setRandomValue] = React.useState(5);
  const [variance, setVariance] = React.useState(50);

  function handleDelete() {}

  function handleClickFilter(event) {
    setOpen(true);
  }

  function handleCloseFilter(event) {
    setOpen(false);
  }
  function handleClickMore(event) {
    setAnchorEl(event.currentTarget);
  }

  function handleCloseMenu() {
    setAnchorEl(null);
  }

  function handleTabChange(event, newValue) {
    setFilterTab(newValue);
  }

  const handleRandomSliderChange = (event, newValue) => {
    setRandomValue(newValue);
  };

  const handleRandomInputChange = event => {
    setRandomValue(event.target.value === "" ? "" : Number(event.target.value));
  };
  const handleVarianceSliderChange = (event, newValue) => {
    setVariance(newValue);
  };

  const handleVarianceInputChange = event => {
    setVariance(event.target.value === "" ? "" : Number(event.target.value));
  };
  return (
    <MuiPickersUtilsProvider utils={DateFnsUtils}>
      <div className={classes.root}>
        <Dialog
          open={open}
          aria-labelledby="form-dialog-title"
          fullWidth={true}
          maxWidth="xl"
        >
          <DialogTitle className={classes.dialogTitle} id="form-dialog-title">
            Adapt Claim Search Criteria
          </DialogTitle>
          <Divider />
          <DialogContent className={classes.dialogContent}>
            <Tabs
              className={classes.tabs}
              value={filterTab}
              indicatorColor="primary"
              textColor="primary"
              onChange={handleTabChange}
              variant="fullWidth"
            >
              <Tab label="Location" />
              <Tab label="Details" />
              <Tab label="Dates" />
            </Tabs>
            <form className={classes.container} noValidate autoComplete="off">
              {filterTab === 0 && (
                <Grid container>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="adornment-region">Region</InputLabel>
                      <Input
                        fullWidth={true}
                        id="adornment-region"
                        type="text"
                        value="Ultha"
                        endAdornment={
                          <InputAdornment position="end">
                            <IconButton size="small">
                              <MoreHoriz />
                            </IconButton>
                          </InputAdornment>
                        }
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="adornment-district">
                        District
                      </InputLabel>
                      <Input
                        fullWidth={true}
                        id="adornment-district"
                        type="text"
                        value="Rapta"
                        endAdornment={
                          <InputAdornment position="end">
                            <IconButton size="small">
                              <MoreHoriz />
                            </IconButton>
                          </InputAdornment>
                        }
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="adornment-hfcode">
                        HF Code
                      </InputLabel>
                      <Input
                        fullWidth={true}
                        id="adornment-hfcode"
                        type="text"
                        value="RADS002 - Kitua Dispensary"
                        endAdornment={
                          <InputAdornment position="end">
                            <IconButton size="small">
                              <MoreHoriz />
                            </IconButton>
                          </InputAdornment>
                        }
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="adornment-hfname">
                        HF Name
                      </InputLabel>
                      <Input type="text" fullWidth={true} />
                    </FormControl>
                  </Grid>
                </Grid>
              )}
              {filterTab === 1 && (
                <Grid container>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="adornment-admin">
                        Administrator
                      </InputLabel>
                      <Input
                        fullWidth={true}
                        id="adornment-admin"
                        type="text"
                        endAdornment={
                          <InputAdornment position="end">
                            <IconButton size="small">
                              <MoreHoriz />
                            </IconButton>
                          </InputAdornment>
                        }
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel>Main Dg.</InputLabel>
                      <Input type="text" fullWidth={true} />
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="visit-type">Visit Type</InputLabel>
                      <Select
                        inputProps={{
                          name: "visitType",
                          id: "visit-type"
                        }}
                      >
                        <MenuItem value="">
                          <em>None</em>
                        </MenuItem>
                        <MenuItem value={10}>Emergency</MenuItem>
                        <MenuItem value={20}>Referrals</MenuItem>
                        <MenuItem value={30}>Other</MenuItem>
                      </Select>
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel>Insurance Number</InputLabel>
                      <Input type="text" fullWidth={true} />
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel>Claim Number</InputLabel>
                      <Input type="text" fullWidth={true} />
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="batch-run">Batch Run</InputLabel>
                      <Select
                        inputProps={{
                          name: "batchRun",
                          id: "batch-run"
                        }}
                      >
                        <MenuItem value="">
                          <em>None</em>
                        </MenuItem>
                      </Select>
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="rev-status">
                        Review Status
                      </InputLabel>
                      <Select
                        inputProps={{
                          name: "revStatus",
                          id: "rev-status"
                        }}
                      >
                        <MenuItem value="">
                          <em>None</em>
                        </MenuItem>
                        <MenuItem value={10}>Idle</MenuItem>
                        <MenuItem value={20}>Not Selected</MenuItem>
                        <MenuItem value={30}>Selected for Review</MenuItem>
                        <MenuItem value={40}>Reviewed</MenuItem>
                        <MenuItem value={50}>ByPassed</MenuItem>
                      </Select>
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="fb-status">
                        Feedback Status
                      </InputLabel>
                      <Select
                        inputProps={{
                          name: "fbStatus",
                          id: "fb-status"
                        }}
                      >
                        <MenuItem value="">
                          <em>None</em>
                        </MenuItem>
                        <MenuItem value={10}>Idle</MenuItem>
                        <MenuItem value={20}>Not Selected</MenuItem>
                        <MenuItem value={30}>Selected for Feedback</MenuItem>
                        <MenuItem value={40}>Delivered</MenuItem>
                        <MenuItem value={50}>ByPassed</MenuItem>
                      </Select>
                    </FormControl>
                  </Grid>
                  <Grid item xs={4} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <InputLabel htmlFor="cla-status">Claim Status</InputLabel>
                      <Select
                        inputProps={{
                          name: "claStatus",
                          id: "cla-status"
                        }}
                      >
                        <MenuItem value="">
                          <em>None</em>
                        </MenuItem>
                        <MenuItem value={10}>Entered</MenuItem>
                        <MenuItem value={20}>Checked</MenuItem>
                        <MenuItem value={30}>Processed</MenuItem>
                        <MenuItem value={40}>Valuated</MenuItem>
                        <MenuItem value={50}>Rejected</MenuItem>
                      </Select>
                    </FormControl>
                  </Grid>
                </Grid>
              )}
              {filterTab === 2 && (
                <Grid container>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Visit Date From"
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <KeyboardDatePicker
                        value={null}
                        margin="normal"
                        id="mui-pickers-date"
                        label="Visit Date To"
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Claim Date From"
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </FormControl>
                  </Grid>
                  <Grid item xs={6} className={classes.item}>
                    <FormControl fullWidth={true} className={classes.formInput}>
                      <KeyboardDatePicker
                        value={null}
                        margin="normal"
                        id="mui-pickers-date"
                        label="Claim Date To"
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </FormControl>
                  </Grid>
                </Grid>
              )}
            </form>
          </DialogContent>
          <Divider />
          <DialogActions>
            <Button onClick={handleCloseFilter} color="primary">
              Cancel
            </Button>
            <Button onClick={handleCloseFilter} color="primary">
              Apply
            </Button>
          </DialogActions>
        </Dialog>
        <Paper className={classes.paper}>
          <Grid container>
            <Grid item xs={9} className={classes.paperHeader}>
              <Typography variant="h6">Claim Filtering</Typography>
            </Grid>
            <Grid container xs={3} justify="flex-end">
              <Grid item className={classes.paperHeaderAction}>
                <IconButton onClick={handleClickFilter}>
                  <SearchIcon />
                </IconButton>
              </Grid>
            </Grid>
            <Grid item xs={12}>
              <Divider />
            </Grid>
            <Grid item xs={12}>
              <Chip
                label="Region: Ultha"
                onDelete={handleDelete}
                className={classes.chip}
              />
              <Chip
                label="District: Rapta"
                onDelete={handleDelete}
                className={classes.chip}
              />
              <Chip
                label="Claim Status: Entered"
                onDelete={handleDelete}
                className={classes.chip}
              />
            </Grid>
            <Grid item xs={12}>
              <Divider />
            </Grid>
            <Grid container xs={12} justify="center" alignItems="center">
              <Grid item xs={3} className={classes.paperHeader}>
                <FormControl className={classes.formInput}>
                  <InputLabel htmlFor="input-random">Random filter</InputLabel>
                  <Input
                    id="adornment-random"
                    value={randomValue}
                    startAdornment={
                      <InputAdornment position="start">%</InputAdornment>
                    }
                    endAdornment={
                      <InputAdornment position="end">
                        <IconButton edge="end">
                          <FilterIcon />
                        </IconButton>
                      </InputAdornment>
                    }
                    inputProps={{
                      step: 10,
                      min: 0,
                      max: 100,
                      type: "number",
                      "aria-label": "Random"
                    }}
                  />
                </FormControl>
              </Grid>
              <Grid item xs={4} className={classes.paperHeader}>
                <Grid container>
                  <Grid item>
                    <FormControl className={classes.formInput}>
                      <InputLabel htmlFor="input-value">
                        Value filter
                      </InputLabel>
                      <Input
                        id="input-value"
                        endAdornment={
                          <InputAdornment position="end">$</InputAdornment>
                        }
                        inputProps={{
                          step: 10,
                          min: 0,
                          max: 100,
                          type: "number",
                          "aria-label": "Value"
                        }}
                      />
                    </FormControl>
                  </Grid>
                  <Grid item>
                    <FormControl className={classes.formInput}>
                      <InputLabel htmlFor="input-variance">Variance</InputLabel>
                      <Input
                        id="input-variance"
                        value={variance}
                        startAdornment={
                          <InputAdornment position="start">%</InputAdornment>
                        }
                        endAdornment={
                          <InputAdornment position="end">
                            <IconButton edge="end">
                              <FilterIcon />
                            </IconButton>
                          </InputAdornment>
                        }
                        inputProps={{
                          step: 10,
                          min: 0,
                          max: 100,
                          type: "number",
                          "aria-label": "Variance"
                        }}
                      />
                    </FormControl>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Grid>
        </Paper>
        <Paper className={classes.paper}>
          <Grid container>
            <Grid item xs={9} className={classes.paperHeader}>
              <Typography variant="h6">2 Claims Found</Typography>
            </Grid>
            <Grid container xs={3} justify="flex-end">
              <Grid item className={classes.paperHeaderAction}>
                <IconButton onClick={handleClickMore}>
                  <MoreHoriz />
                </IconButton>
                <StyledMenu
                  id="customized-menu"
                  anchorEl={anchorEl}
                  keepMounted
                  open={Boolean(anchorEl)}
                  onClose={handleCloseMenu}
                >
                  <StyledMenuItem>
                    <ListItemIcon>
                      <CheckBoxIcon />
                    </ListItemIcon>
                    <ListItemText primary="Select all" />
                  </StyledMenuItem>
                  <StyledMenuItem>
                    <ListItemIcon>
                      <PersonAddIcon />
                    </ListItemIcon>
                    <ListItemText primary="Review selected" />
                  </StyledMenuItem>
                  <StyledMenuItem>
                    <ListItemIcon>
                      <SpeakerNotesOutlinedIcon />
                    </ListItemIcon>
                    <ListItemText primary="Feedback selected" />
                  </StyledMenuItem>
                  <StyledMenuItem>
                    <ListItemIcon>
                      <SendIcon />
                    </ListItemIcon>
                    <ListItemText primary="Process selected" />
                  </StyledMenuItem>
                </StyledMenu>
              </Grid>
            </Grid>
            <Divider />
            <Table className={classes.table} size="small">
              <TableHead>
                <TableRow>
                  <TableCell>Claim No.</TableCell>
                  <TableCell>HF Name</TableCell>
                  <TableCell>Date Claimed</TableCell>
                  <TableCell colspan={3}>Feedback Status</TableCell>
                  <TableCell colspan={3}>Review Status</TableCell>
                  <TableCell>Claimed</TableCell>
                  <TableCell>Approved</TableCell>
                  <TableCell>Claim Status</TableCell>
                  <TableCell />
                </TableRow>
              </TableHead>
              <TableBody>
                {rows.map(row => (
                  <TableRow key={row.name}>
                    <TableCell>{row.a}</TableCell>
                    <TableCell>{row.b}</TableCell>
                    <TableCell>{row.c}</TableCell>
                    <TableCell>{row.d}</TableCell>
                    <TableCell>
                      <IconButton>
                        {row.a === "CIB00001" && <SpeakerNotesOutlinedIcon />}
                        {row.a === "CID00001" && <SpeakerNotesIcon />}
                      </IconButton>
                    </TableCell>
                    <TableCell>
                      <IconButton>
                        {row.a === "CIB00001" && (
                          <SpeakerNotesOffOutlinedIcon />
                        )}
                      </IconButton>
                    </TableCell>
                    <TableCell>{row.e}</TableCell>
                    <TableCell>
                      <IconButton>
                        <PersonAddIcon />
                      </IconButton>
                    </TableCell>{" "}
                    <TableCell>
                      <IconButton>
                        <PersonAddDisabledIcon />
                      </IconButton>
                    </TableCell>
                    <TableCell>{row.f}</TableCell>
                    <TableCell>{row.g}</TableCell>
                    <TableCell>{row.h}</TableCell>
                    <TableCell>
                      <IconButton>
                        <SendIcon />
                      </IconButton>
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
              <TableFooter>
                <TablePagination
                  className={classes.pager}
                  count={2}
                  page={0}
                  rowsPerPage={10}
                  rowsPerPageOptions={[10]}
                />
              </TableFooter>
            </Table>
          </Grid>
        </Paper>
      </div>
    </MuiPickersUtilsProvider>
  );
}
